@@ -1,11 +1,13 @@
 import glob
 import tempfile
+from typing import List
 
 import cv2
-from PIL import Image
+import PIL
+import numpy as np
 
 
-def _img_arrays_to_pil_imgs(frames):
+def _img_arrays_to_pil_imgs(frames: np.ndarray) -> List[PIL.JpegImagePlugin.JpegImageFile]:
     """ Writes cv np.array frames and reloads them in PIL.image format """
     with tempfile.TemporaryDirectory() as tmp:
         for n, frame in enumerate(frames):
@@ -13,6 +15,6 @@ def _img_arrays_to_pil_imgs(frames):
         images_list = []
         image_paths = glob.glob(f"{tmp}/*.jpg")
         for path in image_paths:
-            img = Image.open(path)
+            img = PIL.Image.open(path)
             images_list.append(img)
         return images_list
